0,1,2-fach RGB Dimmer
19,210,Rote Modul LED
17,1,Dimmer 1
17,2,Dimmer 2
17,3,Dimmer 3
17,4,Dimmer 4
17,5,Dimmer 5
17,6,Dimmer 6
22,1,RGB Dimmer 1
22,2,RGB Dimmer 2
16,17,Eingang 1
16,18,Eingang 2
16,19,Eingang 3
16,20,Eingang 4
16,21,Eingang 5
16,22,Eingang 6

