0,1,8-fach Relais
19,210,Rote Modul LED
19,1,Relais 1
19,2,Relais 2
19,3,Relais 3
19,4,Relais 4
19,5,Relais 5
19,6,Relais 6
19,7,Relais 7
19,8,Relais 8
19,9,Relais 9
19,10,Relais 10
19,11,Relais 11
19,12,Relais 12
19,13,Relais 13
19,14,Relais 14
19,15,Relais 15
19,16,Relais 16
19,85,Schalter 85
19,86,Schalter 86
19,87,Schalter 87
19,88,Schalter 88
19,97,Schalter 97
19,98,Schalter 98
19,99,Schalter 99
19,100,Schalter 100
19,101,Schalter 101
19,102,Schalter 102
19,103,Schalter 103
19,104,Schalter 104
17,1,Dimmer 1
17,2,Dimmer 2
17,3,Dimmer 3
17,4,Dimmer 4
17,5,Dimmer 5
17,6,Dimmer 6
17,7,Dimmer 7
17,8,Dimmer 8
18,1,Rolladen 1
18,2,Rolladen 2
18,3,Rolladen 3
18,4,Rolladen 4
18,5,Rolladen 5
18,6,Rolladen 6
18,7,Rolladen 7
18,8,Rolladen 8
16,85,Eingang 85
16,86,Eingang 86
16,87,Eingang 87
16,88,Eingang 88
16,97,Eingang 1
16,98,Eingang 2
16,99,Eingang 3
16,100,Eingang 4
16,101,Eingang 5
16,102,Eingang 6
16,103,Eingang 7
16,104,Eingang 8
32,85,Temmperatur 85
32,86,Temmperatur 86
32,87,Temmperatur 87
32,88,Temmperatur 88
32,97,Temmperatur 97
32,98,Temmperatur 98
32,99,Temmperatur 99
32,100,Temmperatur 100
32,101,Temmperatur 101
32,102,Temmperatur 102
32,103,Temmperatur 103
32,104,Temmperatur 104
34,85,Feuchtigkeit 85
34,86,Feuchtigkeit 86
34,87,Feuchtigkeit 87
34,88,Feuchtigkeit 88
34,97,Feuchtigkeit 97
34,98,Feuchtigkeit 98
34,99,Feuchtigkeit 99
34,100,Feuchtigkeit 100
34,101,Feuchtigkeit 101
34,102,Feuchtigkeit 102
34,103,Feuchtigkeit 103
34,104,Feuchtigkeit 104
42,85,Taupunkt 85
42,86,Taupunkt 86
42,87,Taupunkt 87
42,88,Taupunkt 88
42,97,Taupunkt 97
42,98,Taupunkt 98
42,99,Taupunkt 99
42,100,Taupunkt 100
42,101,Taupunkt 101
42,102,Taupunkt 102
42,103,Taupunkt 103
42,104,Taupunkt 104
44,1,PID-Controller 1
44,2,PID-Controller 2
44,3,PID-Controller 3
44,4,PID-Controller 4