0,1,8-fach Relais
19,210,Rote Modul LED
19,1,Relais 1
19,2,Relais 2
19,3,Relais 3
19,4,Relais 4
19,5,Relais 5
19,6,Relais 6
19,7,Relais 7
19,8,Relais 8
16,97,Eingang 1
16,98,Eingang 2
16,99,Eingang 3
16,100,Eingang 4
16,101,Eingang 5
16,102,Eingang 6
16,103,Eingang 7
16,104,Eingang 8