0,1,32-fach IO Modul
19,210,Rote Modul LED
16,17,Eingang 1,DIGITAL_IN
16,18,Eingang 2,DIGITAL_IN
16,19,Eingang 3,DIGITAL_IN
16,20,Eingang 4,DIGITAL_IN
16,21,Eingang 5,DIGITAL_IN
16,22,Eingang 6,DIGITAL_IN
16,23,Eingang 7,DIGITAL_IN
16,24,Eingang 8,DIGITAL_IN
16,33,Eingang 9,DIGITAL_IN
16,34,Eingang 10,DIGITAL_IN
16,35,Eingang 11,DIGITAL_IN
16,36,Eingang 12,DIGITAL_IN
16,37,Eingang 13,DIGITAL_IN
16,38,Eingang 14,DIGITAL_IN
16,39,Eingang 15,DIGITAL_IN
16,40,Eingang 16,DIGITAL_IN
19,49,Ausgang 1,DIGITAL_OUT
19,50,Ausgang 2,DIGITAL_OUT
19,51,Ausgang 3,DIGITAL_OUT
19,52,Ausgang 4,DIGITAL_OUT
19,53,Ausgang 5,DIGITAL_OUT
19,54,Ausgang 6,DIGITAL_OUT
19,55,Ausgang 7,DIGITAL_OUT
19,56,Ausgang 8,DIGITAL_OUT
19,97,Ausgang 9,DIGITAL_OUT
19,98,Ausgang 10,DIGITAL_OUT
19,99,Ausgang 11,DIGITAL_OUT
19,100,Ausgang 12,DIGITAL_OUT
19,101,Ausgang 13,DIGITAL_OUT
19,102,Ausgang 14,DIGITAL_OUT
19,103,Ausgang 15,DIGITAL_OUT
19,104,Ausgang 16,DIGITAL_OUT
32,1,Temperatursensor 1,TEMPERATURE
32,2,Temperatursensor 2,TEMPERATURE
32,3,Temperatursensor 3,TEMPERATURE
32,4,Temperatursensor 4,TEMPERATURE
32,5,Temperatursensor 5,TEMPERATURE